@@ -4,7 +4,7 @@ val error_notice : parent:#GWindow.window_skel -> string -> unit
 val error_notice_f :
   parent:#GWindow.window_skel -> ('a, unit, string, unit) format4 -> 'a
 
-val nice_fetch : (Database.t -> 'a) -> Database.t -> 'a
+val with_grab  : (unit -> 'a) -> 'a
 val fold_in_loop : ?granularity:int -> ('a -> 'b -> 'a) -> 'a -> 'b list -> 'a
 
 val wrap_in_scroll_window : (GObj.widget -> unit) -> GObj.widget -> unit
@@ -41,9 +41,11 @@ module Open : sig
   val show : t -> string option
 end
 
+(*
 module LockedDB : sig
   val show : #App.t -> [`FAIL | `RETRY]
 end
+*)
 
 type manager
 val make  : unit -> manager * GObj.widget * GObj.widget
