@@ -38,13 +38,11 @@ let string_list_of_item = function
 
 let autocolor_of_item = function
   | `STRING "none" | `BOOL false -> NONE
-  | `STRING "key" | `STRING "keyid" -> BY_KEYID
   | `STRING "author" -> BY_AUTHOR_HASH
   | `STRING "branch" -> BY_BRANCH_HASH
   | _ -> failwith "autocolor_of_item"
 let string_of_autocolor = function
   | NONE -> "none"
-  | BY_KEYID -> "key"
   | BY_AUTHOR_HASH -> "author"
   | BY_BRANCH_HASH -> "branch"
 let item_of_autocolor ac = 
@@ -95,11 +93,11 @@ type text_props = [
   | `FONT of string
   | `WEIGHT of int]
 
-let match_style { autocolor = autocolor_pref ; style = style } g db =
-  let autocolor = Autocolor.autocolor autocolor_pref db in
+let match_style { autocolor = autocolor_pref ; style = style } g mtn =
+  let autocolor = Autocolor.autocolor autocolor_pref in
 
   fun id (default_rect_props, default_txt_props) ->
-    let get_cert n = Database.fetch_cert_value db id n in
+    let get_cert = Monotone.cert_value mtn id in
 
     let matching_attrs = 
       List.fold_left
@@ -154,9 +152,8 @@ let match_style { autocolor = autocolor_pref ; style = style } g db =
       else begin
 	let autocolor_key = 
 	  match autocolor_pref with
-	  | BY_KEYID -> Database.fetch_cert_signer db id "branch"
-	  | BY_AUTHOR_HASH -> Database.fetch_cert_value db id "author"
-	  | BY_BRANCH_HASH -> Database.fetch_cert_value db id "branch"
+	  | BY_AUTHOR_HASH -> get_cert "author"
+	  | BY_BRANCH_HASH -> get_cert "branch"
 	  | NONE -> [] in
 	`FILL_COLOR_RGBA (autocolor autocolor_key) :: cleanup_rect_props 
       end in
@@ -245,7 +242,7 @@ let parse_merge_items (prefs, style) filename =
 let defaults =
   {
    font          = "Monospace 8" ;
-   autocolor     = BY_KEYID ;
+   autocolor     = BY_AUTHOR_HASH ;
    lr_layout     = false ;
    monotone_path = "mtn" ;
    dot_path      = "dot" ;
